#!/usr/bin/env rspec

require_relative "test_helper"

require "yast"

Yast.import "Host"

describe "Host" do
  subject(:host) { Yast::Host }

  describe "#Export" do
    let(:etc_hosts) do
      {
        "127.0.0.1"  => ["localhost localhost.localdomain"],
        "10.20.1.29" => ["beholder"]
      }
    end

    it "Successfully exports stored mapping" do
      host.Import("hosts" => etc_hosts)
      expect(host.Export).to eql("hosts" => etc_hosts)
    end

    it "removes empty name lists" do
      host.Import("hosts" => { "127.0.0.1" => ["localhost"], "10.0.0.1" => [] })
      expect(host.Export).to eql("hosts" => { "127.0.0.1" => ["localhost"] })
    end

    it "exports empty hash when no mapping is defined" do
      host.Import("hosts" => {})
      expect(host.Export).to be_empty
    end
  end

  describe "#Update" do
    let(:etc_hosts) do
      {
        "127.0.0.1" => ["localhost localhost.localdomain"],
        "10.0.0.1"  => ["somehost.example.com  notice-two-spaces"]
      }
    end

    it "doesn't drop records with two spaces" do
      host.Import("hosts" => etc_hosts)
      host.Update("", "newname", ["10.0.0.42"])

      tested_ip = "10.0.0.1"
      expect(host.name_map[tested_ip]).to eql etc_hosts[tested_ip]
    end

    it "doesn't write entry with duplicate hostname" do
      ip = "1.1.1.1"
      hostname = "linux"

      Yast::Host.Update(hostname, hostname, [ip])
      expect(Yast::Host.name_map[ip]).not_to eql ["#{hostname} #{hostname}"]
    end
  end

  describe ".ResolveHostnameToStaticIPs" do
    let(:static_ips) { ["1.1.1.1", "2.2.2.2"] }
    let(:fqhostname) { "sles.suse.de" }

    before(:each) do
      allow(Yast::Host)
        .to receive(:StaticIPs)
        .and_return(static_ips)
      allow(Yast::Hostname).to receive(:MergeFQ).and_return(fqhostname)
    end

    it "doesn't call .Update when an IP already has a hostname" do
      hostname = "linux"

      Yast::Host.Update(hostname, hostname, [static_ips[0]])

      expect(Yast::Host)
        .not_to receive(:Update)
        .with(fqhostname, fqhostname, static_ips)

      Yast::Host.ResolveHostnameToStaticIPs
    end
  end
end
